#include <propeller.h>
#include "i2cbase.h"

#define i2c_float_scl_high (DIRA &= ~SCLMask)
#define i2c_set_scl_low    (DIRA |= SCLMask)
#define i2c_float_sda_high (DIRA &= ~SDAMask)
#define i2c_set_sda_low    (DIRA |= SDAMask)

int i2cBase::SendByte(unsigned char byte)
{
	i2c_float_sda_high;
	i2c_float_scl_high;
	i2c_set_sda_low;
	i2c_set_scl_low;

	waitcnt(CLKFREQ/100 + CNT);
	
    int result;

    __asm__ volatile (
   	"		andn dira, %[SDAMask]       \n\t" /* DIRA &= ~SDAMask (float SDA high) */ 
   	"		andn dira, %[SCLMask]       \n\t" /* DIRA &= ~SCLMask (float SCL high) */
   	"		and  ina,  %[SDAMask] wz, nr\n\t" /* If != 0, ack'd, else nack */
   	"if_z	mov  %[result], #1          \n\t"
   	"if_nz  mov  %[result], #0          \n\t"
   	"		or   dira, %[SCLMask]       \n\t" /* Set scl low */
   	"       or   dira, %[SDAMask]       \n\t" /* Set sda low */
   	
    : /* outputs */
    	[result]   "=r" (result)
    : /* inputs */
    	[SDAMask] "r" (SDAMask),
    	[SCLMask] "r" (SCLMask)
    );
  
	waitcnt(CLKFREQ/100 + CNT);

	i2c_float_scl_high;
	i2c_float_sda_high;

    return result; //Ack or NAK

}

int i2cBase::Initialize(int SCLPin, int SDAPin)
{
	SCLMask = 1 << SCLPin;
	SDAMask = 1 << SDAPin;
	
	//Set pins to input
	i2c_float_scl_high;
	i2c_float_sda_high;
	
	
	//Set outputs low
	OUTA &= ~SCLMask;
	OUTA &= ~SDAMask;
	
	halfCycle = 60;
}
